@@ -99,7 +99,8 @@ public class JavaBridge {
 				javax.accessibility.AccessibleRole role = null;
 				if (source instanceof AccessibleContext ) {
 					role = ((AccessibleContext) source).getAccessibleRole();
-					if ( role == javax.accessibility.AccessibleRole.TEXT ) 
+					if ( (role == javax.accessibility.AccessibleRole.TEXT) 
+					    || role.toDisplayString(java.util.Locale.US).equalsIgnoreCase("paragraph")) 
 					    textEvent = true;
 					else if ( role == javax.accessibility.AccessibleRole.MENU_BAR ) 
 					    dispatchFocusEvent (source);
